pub(crate) fn into_consolidatable_updates_startup(
updates: Vec<StateUpdate>,
ts: Timestamp,
) -> Vec<(StateUpdateKind, Timestamp, Diff)>Expand description
Convert updates into a Vec that can be consolidated by doing the following:
- Update the timestamp of each update to the same value.
- Convert the diff of each update to a type that implements
differential_dataflow::difference::Semigroup.
WARNING: Do not call outside of startup.